@@ -33,7 +33,7 @@ class ShopResource:
         Returns:
             Response: Return Response object of shop list 
         """
-        endpoint = "shops/"
+        endpoint = "shops"
         response = self.auth.request(endpoint, params={"shop_name":shop_name})
         return Response[Shop](**response)
 
